Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(180)

Unified Diff: components/sync/driver/glue/sync_backend_host_impl.h

Issue 2258873003: [Sync] Move sessions/ to engine/cycle/ and rename things to match. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/driver/glue/sync_backend_host_impl.h
diff --git a/components/sync/driver/glue/sync_backend_host_impl.h b/components/sync/driver/glue/sync_backend_host_impl.h
index 1345b9f3c9ce705eca4c5074ac906cd502d1c520..b7e0253620249b074e903e8ba48d2c9e879fc14e 100644
--- a/components/sync/driver/glue/sync_backend_host_impl.h
+++ b/components/sync/driver/glue/sync_backend_host_impl.h
@@ -27,10 +27,10 @@
#include "components/sync/core/sync_manager.h"
#include "components/sync/driver/backend_data_type_configurer.h"
#include "components/sync/driver/glue/sync_backend_host.h"
+#include "components/sync/engine/cycle/sync_cycle_snapshot.h"
+#include "components/sync/engine/cycle/type_debug_info_observer.h"
#include "components/sync/protocol/encryption.pb.h"
#include "components/sync/protocol/sync_protocol_error.h"
-#include "components/sync/sessions/sync_session_snapshot.h"
-#include "components/sync/sessions/type_debug_info_observer.h"
class GURL;
@@ -126,7 +126,7 @@ class SyncBackendHostImpl : public SyncBackendHost,
void EnableEncryptEverything() override;
syncer::UserShare* GetUserShare() const override;
Status GetDetailedStatus() override;
- syncer::sessions::SyncSessionSnapshot GetLastSessionSnapshot() const override;
+ syncer::SyncCycleSnapshot GetLastCycleSnapshot() const override;
bool HasUnsyncedItems() const override;
bool IsNigoriEnabled() const override;
syncer::PassphraseType GetPassphraseType() const override;
@@ -244,7 +244,7 @@ class SyncBackendHostImpl : public SyncBackendHost,
// Called from Core::OnSyncCycleCompleted to handle updating frontend
// thread components.
void HandleSyncCycleCompletedOnFrontendLoop(
- const syncer::sessions::SyncSessionSnapshot& snapshot);
+ const syncer::SyncCycleSnapshot& snapshot);
// Called when the syncer failed to perform a configuration and will
// eventually retry. FinishingConfigurationOnFrontendLoop(..) will be called
@@ -365,8 +365,8 @@ class SyncBackendHostImpl : public SyncBackendHost,
// first set (if available).
base::Time cached_explicit_passphrase_time_;
- // UI-thread cache of the last SyncSessionSnapshot received from syncapi.
- syncer::sessions::SyncSessionSnapshot last_snapshot_;
+ // UI-thread cache of the last SyncCycleSnapshot received from syncapi.
+ syncer::SyncCycleSnapshot last_snapshot_;
invalidation::InvalidationService* invalidator_;
bool invalidation_handler_registered_;
« no previous file with comments | « components/sync/driver/glue/sync_backend_host_core.cc ('k') | components/sync/driver/glue/sync_backend_host_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698